#!/bin/bash

# updated 2015-11-19 for new ffmpeg
#usage: concatparam chapter1 chapter2 chapter3 outputname
#input1.mp4 = chapter1
#input2.mp4 = feature
#input3.mp4 = chapter3

#set PATH appropriately
export PATH=/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin

#set TMPDIR if necessary
${TMPDIR:=/private/tmp}

die () {
  echo $@ >&2
  exit 1;
}
function safetempFile () {

#make a temporary file
local pathName
local pathExt=${1##*.} && test "${pathExt}" = "${1}" && pathExt=
if test "${pathExt}";then
pathName=${1%.${pathExt}}
test "${pathName}" = "${pathName##*/}" && pathName=${TMPDIR%%/}/${pathName}
local tmpFile=$(mktemp ${pathName}.XXXXXX) && mv "${tmpFile}" "${tmpFile}.${pathExt}" && echo "${tmpFile}.${pathExt}" || die failed to make tempfile for ${pathName}
else
  test "${pathName:=${1}}" = "${pathName##*/}" && pathName=${TMPDIR%%/}/${pathName}
  mktemp ${pathName}.XXXXXX || die failed to make tempfile for ${pathName}
fi
}


startdate=$(date +%s)

echo "============ START TIME " $startdate " ==============="
echo "Argument 0 is: $0"		#command
echo "Argument 1 is: $1"		#input1=chapter1
echo "Argument 2 is: [$2]"		#input2=featuremovie
echo "Argument 3 is: $3"		#input3=chapter3
echo "Argument 4 is: $4"		#input4=locationOfTheMergedVideo


chapter1="$1"
chapter2="$2"
chapter3="$3"
mergedmovie="$4"


chapter2trim="$(safetempFile input2trimmed.mp4)"
chapter2scaled="$(safetempFile input2scaled.mp4)"
intermed1="$(safetempFile intermediate 1.ts)"
intermed2="$(safetempFile intermediate 2.ts)"
intermed3="$(safetempFile intermediate 3.ts)"
tmpoutput="$(safetempFile mergedMovie.mp4)"

#rm "$mergedmovie" || die failed to delete old ${mergedmovie}
rm -f "$mergedmovie" || die failed to delete old ${mergedmovie}


#somehow this gets rid of the green
#if we skip this part - we get a second or two of green frames
# between chapter1 and feature in the merged video
#ffmpeg -y -i "$chapter2" -ss 00:00:00 -codec copy -t 200000 "$chapter2trim" &&
ffmpeg -y -i "$chapter1" -c copy -bsf:v h264_mp4toannexb -f mpegts "$intermed1" &&
#ffmpeg -y -i "$chapter2trim" -c:v copy -c:a copy -bsf:v h264_mp4toannexb -f mpegts "$intermed2" &&
ffmpeg -y -i "$chapter2" -c copy -bsf:v h264_mp4toannexb -f mpegts "$intermed2" &&
ffmpeg -y -i "$chapter3" -c copy -bsf:v h264_mp4toannexb -f mpegts "$intermed3" &&
ffmpeg -y -i "concat:$intermed1|$intermed2|$intermed3" -c:v copy -c:a copy -bsf:a aac_adtstoasc "$tmpoutput" || die failed to make merged movie

cp "$tmpoutput" "$mergedmovie" || die failed to copy merged movie

# clean up temp files
rm "$chapter2trim"
rm "$chapter2scaled"
rm "$intermed1"
rm "$intermed2"
rm "$intermed3"
rm "$tmpoutput"





enddate=$(date +%s);

echo ""
echo ""
echo "======================================================================="
echo "START DATE=$startdate"
echo "  END DATE=$enddate"
diff=$(echo $((enddate-startdate)) | awk '{print int($1/60)":"int($1%60)}')
echo "TOTAL ELAPSED TIME:  $diff"
echo "======================================================================="


echo "ALL DONE Now... with script named:" $(basename "$0")
exit 0 # really should return something if outputffmpeg.mp4



START=$(date +%s);
sleep 3; # Your stuff
END=$(date +%s);
diff=$(echo $((END-START)) | awk '{print int($1/60)":"int($1%60)}')
echo "TOTAL ELAPSED TIME:  $diff"
exit 0


